@@ -494,11 +494,14 @@ def get_keywords_metrics(email,api_key,df,match_extract):
             cpc = get_cpc(keywords_list, match=c)
             extract_cpc(cpc)
 
-    fin_df_1 = pd.DataFrame.from_dict(keyword_metrics)
-    fin_df_2 = pd.DataFrame.from_dict(cpc_metrics)
+    fin_df_1 = pd.DataFrame.from_dict(keyword_metrics, orient='index')
+    fin_df_1.transpose()
+    fin_df_2 = pd.DataFrame.from_dict(cpc_metrics, orient='index')
+    fin_df_2.transpose()
     fin_df = pd.merge(left=fin_df_1, right=fin_df_2, how='left', on=['Keywords'])
 
     df = pd.merge(left=df, right=fin_df, how='left', on=['Keywords'])
+    df
 
     return df
 
