@@ -22,8 +22,8 @@ df_scrape_path = 'data/df_scrape.csv' # file name for scraped keywords
 
 #Credentials/Setting for google
 google = True # keep true if you want to download ideas from google keywords api
-path = '/home/maunish/Upwork Projects/Google-Ads-Project/examples/google-ads.yaml'
-customer_id = '6554081276' #google ads customer id
+path = 'google-ads.yaml'
+customer_id = '8306215642' #google ads customer id
 df_google_path = 'data/df_google.csv'
 
 df_final_path = 'data/df_final.csv'
