@@ -8,8 +8,8 @@ from autoads.gads import create_adgroup,create_campaign,create_keyword,_handle_g
 
 df_path = 'data/keywords_to_upload.csv' # specify keywords to uplod csv here
 save_path = 'data'
-path = '/home/maunish/Upwork Projects/Google-Ads-Project/examples/google-ads.yaml'
-customer_id = '6554081276'
+path = 'google-ads.yaml'
+customer_id = '8306215642' #google ads customer id
 
 os.makedirs(save_path,exist_ok=True)
 os.makedirs(save_path+'/history',exist_ok=True)
